Coroutine contract: the MsgraphCoroutine trait, its MsgraphYield /
MsgraphCoroutineState, and the msgraph_try! macro (the coroutine
equivalent of ?).
Enums
- Msgraph
Coroutine State - State returned by every
MsgraphCoroutine::resumecall: either an I/O request to fulfil, or the coroutine’s final value. - Msgraph
Yield - I/O request yielded by a Microsoft Graph coroutine: a Graph call is I/O-only, so reading and writing bytes are the only requests.
Traits
- Msgraph
Coroutine - An I/O-free Microsoft Graph coroutine, resumed with the bytes read
by the caller (or
Nonewhen there is nothing to feed back).