pub enum MsgraphYield {
WantsRead,
WantsWrite(Vec<u8>),
}Expand description
I/O request yielded by a Microsoft Graph coroutine: a Graph call is I/O-only, so reading and writing bytes are the only requests.
Variants
WantsRead
The caller reads from its stream and resumes with the bytes.
WantsWrite(Vec<u8>)
The caller writes the given bytes to its stream and resumes.