MsgraphCoroutine

Trait MsgraphCoroutine 

pub trait MsgraphCoroutine {
    type Yield;
    type Return;

    // Required method
    fn resume(
        &mut self,
        arg: Option<&[u8]>,
    ) -> MsgraphCoroutineState<Self::Yield, Self::Return>;
}
An I/O-free Microsoft Graph coroutine, resumed with the bytes read by the caller (or None when there is nothing to feed back).

Required Associated Types

type Yield

The I/O request type yielded while the coroutine progresses.

type Return

The final value produced on completion.

Required Methods

fn resume( &mut self, arg: Option<&[u8]>, ) -> MsgraphCoroutineState<Self::Yield, Self::Return>

Advances the coroutine with the outcome of the previous yield.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl MsgraphCoroutine for MsgraphAttachmentCreate

Source

impl MsgraphCoroutine for MsgraphAttachmentDelete

Source

impl MsgraphCoroutine for MsgraphAttachmentGetRaw

Source

impl MsgraphCoroutine for MsgraphAttachmentsList

Source

impl MsgraphCoroutine for MsgraphContactChildFoldersList

Source

impl MsgraphCoroutine for MsgraphContactCreate

Source

impl MsgraphCoroutine for MsgraphContactDelete

Source

impl MsgraphCoroutine for MsgraphContactFolderCreate

Source

impl MsgraphCoroutine for MsgraphContactFolderDelete

Source

impl MsgraphCoroutine for MsgraphContactFolderGet

Source

impl MsgraphCoroutine for MsgraphContactFolderUpdate

Source

impl MsgraphCoroutine for MsgraphContactFoldersList

Source

impl MsgraphCoroutine for MsgraphContactGet

Source

impl MsgraphCoroutine for MsgraphContactUpdate

Source

impl MsgraphCoroutine for MsgraphContactsDelta

Source

impl MsgraphCoroutine for MsgraphContactsList

Source

impl MsgraphCoroutine for MsgraphMailChildFoldersList

Source

impl MsgraphCoroutine for MsgraphMailFolderCopy

Source

impl MsgraphCoroutine for MsgraphMailFolderCreate

Source

impl MsgraphCoroutine for MsgraphMailFolderDelete

Source

impl MsgraphCoroutine for MsgraphMailFolderGet

Source

impl MsgraphCoroutine for MsgraphMailFolderMove

Source

impl MsgraphCoroutine for MsgraphMailFolderUpdate

Source

impl MsgraphCoroutine for MsgraphMailFoldersList

Source

impl MsgraphCoroutine for MsgraphMailSend

Source

impl MsgraphCoroutine for MsgraphMailSendMime

Source

impl MsgraphCoroutine for MsgraphMessageCopy

Source

impl MsgraphCoroutine for MsgraphMessageCreate

Source

impl MsgraphCoroutine for MsgraphMessageCreateMime

Source

impl MsgraphCoroutine for MsgraphMessageDelete

Source

impl MsgraphCoroutine for MsgraphMessageGet

Source

impl MsgraphCoroutine for MsgraphMessageGetRaw

Source

impl MsgraphCoroutine for MsgraphMessageMove

Source

impl MsgraphCoroutine for MsgraphMessageSend

Source

impl MsgraphCoroutine for MsgraphMessageUpdate

Source

impl MsgraphCoroutine for MsgraphMessagesDelta

Source

impl MsgraphCoroutine for MsgraphMessagesList

Source

impl MsgraphCoroutine for MsgraphUserGet

Source

impl<T: DeserializeOwned> MsgraphCoroutine for MsgraphSend<T>