pub trait MsgraphStream:
Read
+ Write
+ Send
+ Any {
// Required method
fn as_any_mut(&mut self) -> &mut dyn Any;
}Available on crate feature
client only.Expand description
Blocking stream the client runs over, downcastable through Any
(e.g. to recover a concrete TLS stream).
Required Methods
Sourcefn as_any_mut(&mut self) -> &mut dyn Any
fn as_any_mut(&mut self) -> &mut dyn Any
The stream as a mutable Any, ready for downcasting.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".