Microsoft Graph user resource (users, or the me shortcut),
including its mail folders, messages, the sendMail action, contact
folders and contacts.
Modules
- contact_
folders - Microsoft Graph contact folders (
users.contactFolders): list, get, create, update, delete, list child folders. - contacts
- Microsoft Graph contacts (
users.contacts): list, delta, get, create, update, delete. - get
- Get a Microsoft Graph user (
GET /me,GET /users/{id}). - mail_
folders - Microsoft Graph mail folders (
users.mailFolders): list, get, create, update, delete, copy, move, list child folders. - messages
- Microsoft Graph messages (
users.messages): list, delta, get (JSON and raw MIME), create draft (JSON and raw MIME), update, delete, move, copy, send and the nested attachments collection. - send_
mail - Send a Microsoft Graph message (
POST /me/sendMail) in JSON or MIME format; the message is saved to Sent Items.
Structs
- Msgraph
User - A Microsoft Graph user (the signed-in mailbox owner via
me).