pub struct MsgraphContactsList { /* private fields */ }Expand description
Lists the Microsoft Graph contacts of a contact folder.
Implementations
Sourceimpl MsgraphContactsList
impl MsgraphContactsList
Sourcepub fn new(
auth: &HttpAuthBearer,
user_id: &str,
folder: Option<&str>,
params: &MsgraphContactsListParams<'_>,
) -> Result<Self, MsgraphSendError>
pub fn new( auth: &HttpAuthBearer, user_id: &str, folder: Option<&str>, params: &MsgraphContactsListParams<'_>, ) -> Result<Self, MsgraphSendError>
Lists contacts in the default Contacts folder, or in folder
when given (a contact folder id).