pub struct MsgraphMessageCreateMime { /* private fields */ }Expand description
Creates a Microsoft Graph draft message from raw RFC 5322 MIME.
Implementations
Sourceimpl MsgraphMessageCreateMime
impl MsgraphMessageCreateMime
Sourcepub fn new(
auth: &HttpAuthBearer,
user_id: &str,
folder: Option<&str>,
raw: &[u8],
) -> Result<Self, MsgraphSendError>
pub fn new( auth: &HttpAuthBearer, user_id: &str, folder: Option<&str>, raw: &[u8], ) -> Result<Self, MsgraphSendError>
Creates the draft in the mailbox root, or in folder when given
(a folder id or a well-known name such as drafts).