pub struct MsgraphMessagesList { /* private fields */ }Expand description
Lists the Microsoft Graph messages of a mailbox or mail folder.
Implementations
Sourceimpl MsgraphMessagesList
impl MsgraphMessagesList
Sourcepub fn new(
auth: &HttpAuthBearer,
user_id: &str,
folder: Option<&str>,
params: &MsgraphMessagesListParams<'_>,
) -> Result<Self, MsgraphSendError>
pub fn new( auth: &HttpAuthBearer, user_id: &str, folder: Option<&str>, params: &MsgraphMessagesListParams<'_>, ) -> Result<Self, MsgraphSendError>
Lists messages in the whole mailbox, or in folder when given (a
folder id or a well-known name such as inbox).