MsgraphSend

Struct MsgraphSend 

pub struct MsgraphSend<T> { /* private fields */ }
I/O-free coroutine sending one authorized Microsoft Graph request and parsing its JSON response into T.

Implementations

Source

impl<T: DeserializeOwned> MsgraphSend<T>

pub fn get(auth: &HttpAuthBearer, url: Url) -> Self

Builds a GET send for the given URL.

pub fn delete(auth: &HttpAuthBearer, url: Url) -> Self

Builds a DELETE send for the given URL.

pub fn post_json<B: Serialize>( auth: &HttpAuthBearer, url: Url, body: &B, ) -> Result<Self, MsgraphSendError>

Builds a POST send with a JSON body.

pub fn patch_json<B: Serialize>( auth: &HttpAuthBearer, url: Url, body: &B, ) -> Result<Self, MsgraphSendError>

Builds a PATCH send with a JSON body.

pub fn post_text(auth: &HttpAuthBearer, url: Url, body: Vec<u8>) -> Self

Builds a POST send with a text/plain body.

pub fn with_method( auth: &HttpAuthBearer, method: &str, url: Url, content_type: Option<&str>, body: Vec<u8>, ) -> Self

Builds a send with an arbitrary method, content type and body.