pub trait MsgraphCoroutine {
type Yield;
type Return;
// Required method
fn resume(
&mut self,
arg: Option<&[u8]>,
) -> MsgraphCoroutineState<Self::Yield, Self::Return>;
}Expand description
An I/O-free Microsoft Graph coroutine, resumed with the bytes read
by the caller (or None when there is nothing to feed back).
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".